"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _Fade = _interopRequireDefault(require("@material-ui/core/Fade"));

var _colorManipulator = require("@material-ui/core/styles/colorManipulator");

var _makeStyles = _interopRequireDefault(require("@material-ui/core/styles/makeStyles"));

var _Close = _interopRequireDefault(require("@material-ui/icons/Close"));

var _clsx = _interopRequireDefault(require("clsx"));

var _react = _interopRequireDefault(require("react"));

var _Typography = _interopRequireDefault(require("./Typography"));

/**
 * Emulates the bootstrap alert boxes
 */
var useStyles = (0, _makeStyles.default)(function (theme) {
  // @ts-ignore
  var htmlFontSize = theme.typography.htmlFontSize;
  var coef = theme.typography.fontSize / 14;

  var pxToRem = function pxToRem(size) {
    return "".concat(size / htmlFontSize * coef, "rem");
  };

  var bootstrapColors = {
    primary: {
      color: theme.palette.primary.dark,
      backgroundColor: (0, _colorManipulator.fade)((0, _colorManipulator.lighten)(theme.palette.primary.light, 0.7), 0.8),
      borderColor: (0, _colorManipulator.fade)((0, _colorManipulator.lighten)(theme.palette.primary.light, 0.5), 0.8)
    },
    secondary: {
      color: theme.palette.secondary.dark,
      backgroundColor: (0, _colorManipulator.fade)((0, _colorManipulator.lighten)(theme.palette.secondary.light, 0.7), 0.8),
      borderColor: (0, _colorManipulator.fade)((0, _colorManipulator.lighten)(theme.palette.secondary.light, 0.5), 0.8)
    },
    success: {
      color: "#155724",
      backgroundColor: (0, _colorManipulator.fade)("#d4edda", 0.8),
      borderColor: (0, _colorManipulator.fade)("#c3e6cb", 0.8)
    },
    danger: {
      color: "#721c24",
      backgroundColor: (0, _colorManipulator.fade)("#f8d7da", 0.8),
      borderColor: (0, _colorManipulator.fade)("#f5c6cb", 0.8)
    },
    warning: {
      color: "#856404",
      backgroundColor: (0, _colorManipulator.fade)("#fff3cd", 0.8),
      borderColor: (0, _colorManipulator.fade)("#ffeeba", 0.8)
    },
    info: {
      color: "#0c5460",
      backgroundColor: (0, _colorManipulator.fade)("#d1ecf1", 0.8),
      borderColor: (0, _colorManipulator.fade)("#bee5eb", 0.8)
    },
    light: {
      color: theme.palette.text.secondary,
      backgroundColor: theme.palette.background.paper,
      borderColor: (0, _colorManipulator.fade)(theme.palette.text.secondary, 0.1)
    },
    dark: {
      color: theme.palette.text.primary,
      backgroundColor: (0, _colorManipulator.fade)(theme.palette.text.primary, 0.25),
      borderColor: (0, _colorManipulator.fade)(theme.palette.text.primary, 0.2)
    }
  };

  function getColor(x) {
    return bootstrapColors[x.color === undefined ? "danger" : x.color];
  }

  return {
    root: {
      color: function color(x) {
        return getColor(x).color;
      },
      backgroundColor: function backgroundColor(x) {
        return getColor(x).backgroundColor;
      },
      borderColor: function borderColor(x) {
        return getColor(x).borderColor;
      },
      position: "relative",
      border: "1px solid",
      padding: "".concat(pxToRem(12), " ").concat(pxToRem(14)),
      paddingRight: "".concat(pxToRem(28)),
      borderRadius: pxToRem(4),
      "& a": {
        color: function color(x) {
          return getColor(x).color;
        }
      },
      "& p": {
        margin: 0
      }
    },
    closeIcon: {
      fontSize: pxToRem(18),
      right: 12,
      position: "absolute",
      cursor: "pointer",
      "&:hover": {
        color: "#333"
      }
    },

    /* Styles applied to the root element if `maxWidth="xs"`. */
    maxWidthXs: (0, _defineProperty2.default)({}, theme.breakpoints.up("xs"), {
      maxWidth: Math.max(theme.breakpoints.values.xs, 444)
    }),

    /* Styles applied to the root element if `maxWidth="sm"`. */
    maxWidthSm: (0, _defineProperty2.default)({}, theme.breakpoints.up("sm"), {
      maxWidth: theme.breakpoints.values.sm
    }),

    /* Styles applied to the root element if `maxWidth="md"`. */
    maxWidthMd: (0, _defineProperty2.default)({}, theme.breakpoints.up("md"), {
      maxWidth: theme.breakpoints.values.md
    }),

    /* Styles applied to the root element if `maxWidth="lg"`. */
    maxWidthLg: (0, _defineProperty2.default)({}, theme.breakpoints.up("lg"), {
      maxWidth: theme.breakpoints.values.lg
    }),

    /* Styles applied to the root element if `maxWidth="xl"`. */
    maxWidthXl: (0, _defineProperty2.default)({}, theme.breakpoints.up("xl"), {
      maxWidth: theme.breakpoints.values.xl
    })
  };
});

function Alert(props) {
  var classes = useStyles(props);

  var _React$useState = _react.default.useState(true),
      _React$useState2 = (0, _slicedToArray2.default)(_React$useState, 2),
      show = _React$useState2[0],
      setShow = _React$useState2[1];

  _react.default.useEffect(function () {
    if (props.show !== undefined) {
      setShow(props.show);
    }
  }, [props.show]);

  function handleDismiss() {
    setShow(false);

    if (props.onClose !== undefined) {
      props.onClose();
    }
  }

  var maxWidthClass = classes.maxWidthMd;

  switch (props.maxWidth) {
    case "xl":
      maxWidthClass = classes.maxWidthXl;
      break;

    case "lg":
      maxWidthClass = classes.maxWidthLg;
      break;

    case "md":
      maxWidthClass = classes.maxWidthMd;
      break;

    case "sm":
      maxWidthClass = classes.maxWidthSm;
      break;

    case "xs":
      maxWidthClass = classes.maxWidthXs;
      break;
  }

  return _react.default.createElement(_Fade.default, {
    in: show,
    unmountOnExit: true
  }, _react.default.createElement("div", {
    className: (0, _clsx.default)(classes.root, maxWidthClass)
  }, props.dismissible && _react.default.createElement(_Close.default, {
    onClick: handleDismiss,
    className: classes.closeIcon,
    color: "inherit"
  }), _react.default.createElement(_Typography.default, {
    color: "inherit"
  }, props.children)));
}

var useStylesForHeading = (0, _makeStyles.default)({
  icon: {
    marginRight: 10,
    verticalAlign: -6,
    "& > *:first-child": {
      fontSize: 32
    }
  }
});

function Heading(props) {
  var classes = useStylesForHeading();
  return _react.default.createElement(_Typography.default, {
    color: "inherit",
    variant: "h5",
    component: "h2"
  }, props.icon && _react.default.createElement("span", {
    className: classes.icon
  }, props.icon), props.children);
}

Alert.Heading = Heading;
var _default = Alert;
exports.default = _default;