"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _Button = _interopRequireDefault(require("@material-ui/core/Button"));

var _colorManipulator = require("@material-ui/core/styles/colorManipulator");

var _makeStyles = _interopRequireDefault(require("@material-ui/styles/makeStyles"));

var _react = _interopRequireDefault(require("react"));

var useStyles = (0, _makeStyles.default)(function (theme) {
  var bootstrapColors = {
    primary: {
      contrastText: theme.palette.primary.contrastText,
      main: theme.palette.primary.main
    },
    secondary: {
      contrastText: theme.palette.secondary.contrastText,
      main: theme.palette.secondary.main
    },
    success: {
      contrastText: "#fff",
      main: "#218838"
    },
    danger: {
      contrastText: "#fff",
      main: "#c82333"
    },
    warning: {
      contrastText: "#333",
      main: "#e0a800"
    },
    info: {
      contrastText: "#fff",
      main: "#138496"
    },
    light: {
      contrastText: theme.palette.text.secondary,
      main: theme.palette.background.paper
    },
    dark: {
      contrastText: theme.palette.background.paper,
      main: theme.palette.text.primary
    }
  };

  function getColor(x) {
    return bootstrapColors[x.color === undefined ? "dark" : x.color];
  } // @ts-ignore


  var htmlFontSize = theme.typography.htmlFontSize;
  var coef = theme.typography.fontSize / 14;

  var pxToRem = function pxToRem(size) {
    return "".concat(size / htmlFontSize * coef, "rem");
  };

  return {
    root: {
      textTransform: "none",
      boxShadow: "none",
      borderRadius: pxToRem(4),
      padding: function padding(x) {
        return "".concat(pxToRem(x.size === "large" ? 19 : x.size === "medium" ? 15 : 13), " ").concat(x.size === "large" ? 19 : x.size === "medium" ? 15 : 13);
      },
      fontSize: function fontSize(x) {
        return pxToRem(x.size === "large" ? 19 : x.size === "medium" ? 15 : 13);
      },
      lineHeight: "1.5",
      "&.Mui-disabled": {
        opacity: 0.3
      },
      "&.MuiButton-contained": {
        color: function color(x) {
          return getColor(x).contrastText;
        },
        backgroundColor: function backgroundColor(x) {
          return getColor(x).main;
        },
        border: function border(x) {
          return "1px solid ".concat((0, _colorManipulator.fade)((0, _colorManipulator.darken)(getColor(x).main, 0.3), 0.3));
        },
        "&:hover": {
          backgroundColor: function backgroundColor(x) {
            return (0, _colorManipulator.darken)(getColor(x).main, 0.25);
          }
        }
      },
      "&.MuiButton-outlined,&.MuiButton-text": {
        color: function color(x) {
          return x.color === "light" ? getColor(x).contrastText : getColor(x).main;
        },
        borderColor: function borderColor(x) {
          return x.color === "light" ? (0, _colorManipulator.fade)((0, _colorManipulator.darken)(getColor(x).main, 0.3), 0.3) : getColor(x).main;
        },
        "&:hover": {
          backgroundColor: function backgroundColor(x) {
            return x.color === "light" ? (0, _colorManipulator.fade)((0, _colorManipulator.lighten)(getColor(x).contrastText, 0.2), 0.15) : (0, _colorManipulator.fade)((0, _colorManipulator.lighten)(getColor(x).main, 0.2), 0.15);
          },
          borderColor: function borderColor(x) {
            return x.color === "light" ? (0, _colorManipulator.lighten)(getColor(x).contrastText, 0.5) : (0, _colorManipulator.lighten)(getColor(x).main, 0.5);
          },
          color: function color(x) {
            return x.color === "light" ? (0, _colorManipulator.lighten)(getColor(x).contrastText, 0.3) : (0, _colorManipulator.lighten)(getColor(x).main, 0.3);
          }
        }
      },
      "&:hover": {
        boxShadow: "none"
      }
    }
  };
});

var Button = _react.default.forwardRef(function BootstrapButton(props, ref) {
  var classes = useStyles(props);
  var color = props.color,
      otherProps = (0, _objectWithoutProperties2.default)(props, ["color"]);
  return _react.default.createElement(_Button.default, (0, _extends2.default)({}, otherProps, {
    classes: classes,
    ref: ref
  }));
});

Button.defaultProps = {
  size: "medium",
  color: "dark"
};
var _default = Button;
exports.default = _default;